==> opencart-4.1.0.0.zip: upload/admin/language/fr-fr/catalog/category.php <==
<?php
// Heading
$_['heading_title']           = 'Catégories';

// Text
$_['text_success']            = 'Succès: Vous avez modifié les catégories!';
$_['text_list']               = 'Liste des Catégories';
$_['text_add']                = 'Ajouter une Catégorie';
$_['text_edit']               = 'Modifier la Catégorie';
$_['text_default']            = 'Par Défaut';
$_['text_keyword']            = 'N\'utilisez pas d\'espaces, remplacez plutôt les espaces par - et assurez-vous que l\'URL SEO soit unique à l\'échelle mondiale.';

// Column
$_['column_name']             = 'Nom de la Catégorie';
$_['column_sort_order']       = 'Ordre de Tri';
$_['column_action']           = 'Action';

// Entry
$_['entry_name']              = 'Nom de la Catégorie';
$_['entry_description']       = 'Description';
$_['entry_meta_title']        = 'Titre de la Balise Meta';
$_['entry_meta_keyword']      = 'Mots-clés de la Balise Meta';
$_['entry_meta_description']  = 'Description de la Balise Meta';
$_['entry_store']             = 'Magasins';
$_['entry_keyword']           = 'Mot-clé';
$_['entry_parent']            = 'Parent';
$_['entry_filter']            = 'Filtres';
$_['entry_image']             = 'Image';
$_['entry_top']               = 'Haut';
$_['entry_column']            = 'Colonnes';
$_['entry_sort_order']        = 'Ordre de Tri';
$_['entry_status']            = 'Statut';
$_['entry_layout']            = 'Remplacement de la Disposition';

// Help
$_['help_parent']             = '(Autocomplétion)';
$_['help_filter']             = '(Autocomplétion)';
$_['help_top']                = 'Afficher dans la barre de menu du haut. Fonctionne uniquement pour les catégories parentes principales.';
$_['help_column']             = 'Nombre de colonnes à utiliser pour les 3 catégories inférieures. Fonctionne uniquement pour les catégories parentes principales.';

// Error
$_['error_warning']           = 'Attention: Veuillez vérifier attentivement le formulaire pour les erreurs!';
$_['error_permission']        = 'Attention: Vous n\'avez pas la permission de modifier les catégories!';
$_['error_name']              = 'Le nom de la catégorie doit contenir entre 1 et 255 caractères!';
$_['error_meta_title']        = 'Le titre Meta doit contenir plus de 1 caractère et moins de 255 caractères!';
$_['error_parent']            = 'La catégorie parente que vous avez choisie est un enfant de la catégorie actuelle!';
$_['error_keyword']           = 'L\'URL SEO doit contenir entre 1 et 64 caractères!';
$_['error_keyword_exists']    = 'L\'URL SEO doit être unique!';
$_['error_keyword_character'] = 'Le mot-clé ne peut utiliser que les caractères a-z, 0-9, - et _ !';

==> opencart-4.1.0.3.zip: upload/admin/language/fr-fr/catalog/category.php <==
<?php
// En-tête
$_['heading_title']           = 'Catégories';

// Texte
$_['text_success']            = 'Succès: Vous avez modifié les catégories!';
$_['text_list']               = 'Liste des Catégories';
$_['text_add']                = 'Ajouter une Catégorie';
$_['text_edit']               = 'Modifier la Catégorie';
$_['text_filter']             = 'Filtre';
$_['text_default']            = 'Par Défaut';
$_['text_keyword']            = 'N\'utilisez pas d\'espaces, remplacez plutôt les espaces par - et assurez-vous que l\'URL SEO soit unique à l\'échelle mondiale.';

// Colonne
$_['column_image']            = 'Image';
$_['column_name']             = 'Nom de la Catégorie';
$_['column_sort_order']       = 'Ordre de Tri';
$_['column_action']           = 'Action';

// Entrée
$_['entry_name']              = 'Nom de la Catégorie';
$_['entry_description']       = 'Description';
$_['entry_meta_title']        = 'Titre de la Balise Meta';
$_['entry_meta_keyword']      = 'Mots-clés de la Balise Meta';
$_['entry_meta_description']  = 'Description de la Balise Meta';
$_['entry_store']             = 'Magasins';
$_['entry_keyword']           = 'Mot-clé';
$_['entry_parent']            = 'Parent';
$_['entry_filter']            = 'Filtres';
$_['entry_image']             = 'Image';
$_['entry_sort_order']        = 'Ordre de Tri';
$_['entry_status']            = 'Statut';
$_['entry_layout']            = 'Remplacement de la Disposition';

// Aide
$_['help_parent']             = '(Autocomplétion)';
$_['help_filter']             = '(Autocomplétion)';

// Erreur
$_['error_warning']           = 'Attention: Veuillez vérifier attentivement le formulaire pour les erreurs!';
$_['error_permission']        = 'Attention: Vous n\'avez pas la permission de modifier les catégories!';
$_['error_name']              = 'Le nom de la catégorie doit contenir entre 1 et 255 caractères!';
$_['error_meta_title']        = 'Le titre Meta doit contenir plus de 1 caractère et moins de 255 caractères!';
$_['error_parent']            = 'La catégorie parente que vous avez choisie est un enfant de la catégorie actuelle!';
$_['error_keyword']           = 'L\'URL SEO doit contenir entre 1 et 64 caractères!';
$_['error_keyword_exists']    = 'L\'URL SEO doit être unique!';
$_['error_keyword_character'] = 'Le mot-clé ne peut utiliser que les caractères a-z, 0-9, - et _ !';
